### cleansor

This is a duplicate file detector and cleansor. It finds all file(s) with the extension name entered in the current directory and its subdirectories, calculates their hashes, and stores them in a dictionary. If a hash already exists in the dictionary, it means there's a duplicate file. Finally, it deletes the duplicate files found.

#### install it via (pip/pip3):
```
pip install cleansor
```

#### execute the cleansor by (python/python3):
```
python -m cleansor
```

Enter your file extension name (without the dot) then you are good to go!